You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@geode.apache.org by hi...@apache.org on 2016/09/15 02:00:06 UTC

[45/65] [abbrv] [partial] incubator-geode git commit: GEODE-37 changed import to org.apache.geode

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/admin/DistributedSystemConfig.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/admin/SystemMemberBridgeServer.java b/geode-core/src/main/java/org/apache/geode/admin/SystemMemberBridgeServer.java
index bc95925..71fb7e1 100644
--- a/geode-core/src/main/java/org/apache/geode/admin/SystemMemberBridgeServer.java
+++ b/geode-core/src/main/java/org/apache/geode/admin/SystemMemberBridgeServer.java
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.admin;
+package org.apache.geode.admin;
 
-import com.gemstone.gemfire.cache.server.ServerLoadProbe;
+import org.apache.geode.cache.server.ServerLoadProbe;
 
 /**
  * Administrative interface that represents a CacheServer that
@@ -84,7 +84,7 @@ public interface SystemMemberBridgeServer {
    * <p>Setting a specific bind address will cause the bridge server to always
    * use this address and ignore any address specified by "server-bind-address"
    * or "bind-address" in the <code>gemfire.properties</code> file
-   * (see {@link com.gemstone.gemfire.distributed.DistributedSystem}
+   * (see {@link org.apache.geode.distributed.DistributedSystem}
    * for a description of these properties).
    * <p> A <code>null</code> value will be treated the same as the default "".
    * <p> The default value does not override the gemfire.properties. If you wish to

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/admin/SystemMemberCache.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/admin/internal/AbstractHealthEvaluator.java b/geode-core/src/main/java/org/apache/geode/admin/internal/AbstractHealthEvaluator.java
index 4b6505f..1a98c99 100644
--- a/geode-core/src/main/java/org/apache/geode/admin/internal/AbstractHealthEvaluator.java
+++ b/geode-core/src/main/java/org/apache/geode/admin/internal/AbstractHealthEvaluator.java
@@ -14,18 +14,18 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.admin.internal;
+package org.apache.geode.admin.internal;
 
 import java.util.List;
 
 import org.apache.logging.log4j.Logger;
 
-import com.gemstone.gemfire.admin.GemFireHealth;
-import com.gemstone.gemfire.admin.GemFireHealthConfig;
-import com.gemstone.gemfire.distributed.internal.DM;
-import com.gemstone.gemfire.internal.i18n.LocalizedStrings;
-import com.gemstone.gemfire.internal.logging.LogService;
-import com.gemstone.gemfire.internal.logging.log4j.LocalizedMessage;
+import org.apache.geode.admin.GemFireHealth;
+import org.apache.geode.admin.GemFireHealthConfig;
+import org.apache.geode.distributed.internal.DM;
+import org.apache.geode.internal.i18n.LocalizedStrings;
+import org.apache.geode.internal.logging.LogService;
+import org.apache.geode.internal.logging.log4j.LocalizedMessage;
 
 /**
  * The abstract superclass of all GemFire health evaluators.

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/admin/internal/AdminDistributedSystemImpl.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/admin/internal/AdminDistributedSystemImpl.java b/geode-core/src/main/java/org/apache/geode/admin/internal/AdminDistributedSystemImpl.java
index 25dce1d..aba79d2 100755
--- a/geode-core/src/main/java/org/apache/geode/admin/internal/AdminDistributedSystemImpl.java
+++ b/geode-core/src/main/java/org/apache/geode/admin/internal/AdminDistributedSystemImpl.java
@@ -14,32 +14,32 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.admin.internal;
-
-import com.gemstone.gemfire.CancelException;
-import com.gemstone.gemfire.SystemFailure;
-import com.gemstone.gemfire.admin.*;
-import com.gemstone.gemfire.admin.Alert;
-import com.gemstone.gemfire.admin.AlertListener;
-import com.gemstone.gemfire.cache.persistence.PersistentID;
-import com.gemstone.gemfire.distributed.DistributedMember;
-import com.gemstone.gemfire.distributed.FutureCancelledException;
-import com.gemstone.gemfire.distributed.internal.*;
-import com.gemstone.gemfire.distributed.internal.membership.InternalDistributedMember;
-import com.gemstone.gemfire.internal.Assert;
-import com.gemstone.gemfire.internal.Banner;
-import com.gemstone.gemfire.internal.admin.*;
-import com.gemstone.gemfire.internal.admin.remote.*;
-import com.gemstone.gemfire.internal.cache.persistence.PersistentMemberPattern;
-import com.gemstone.gemfire.internal.i18n.LocalizedStrings;
-import com.gemstone.gemfire.internal.logging.InternalLogWriter;
-import com.gemstone.gemfire.internal.logging.LogService;
-import com.gemstone.gemfire.internal.logging.LogWriterFactory;
-import com.gemstone.gemfire.internal.logging.log4j.LocalizedMessage;
-import com.gemstone.gemfire.internal.logging.log4j.LogMarker;
-import com.gemstone.gemfire.internal.logging.log4j.LogWriterAppender;
-import com.gemstone.gemfire.internal.logging.log4j.LogWriterAppenders;
-import com.gemstone.gemfire.internal.util.concurrent.FutureResult;
+package org.apache.geode.admin.internal;
+
+import org.apache.geode.CancelException;
+import org.apache.geode.SystemFailure;
+import org.apache.geode.admin.*;
+import org.apache.geode.admin.Alert;
+import org.apache.geode.admin.AlertListener;
+import org.apache.geode.cache.persistence.PersistentID;
+import org.apache.geode.distributed.DistributedMember;
+import org.apache.geode.distributed.FutureCancelledException;
+import org.apache.geode.distributed.internal.*;
+import org.apache.geode.distributed.internal.membership.InternalDistributedMember;
+import org.apache.geode.internal.Assert;
+import org.apache.geode.internal.Banner;
+import org.apache.geode.internal.admin.*;
+import org.apache.geode.internal.admin.remote.*;
+import org.apache.geode.internal.cache.persistence.PersistentMemberPattern;
+import org.apache.geode.internal.i18n.LocalizedStrings;
+import org.apache.geode.internal.logging.InternalLogWriter;
+import org.apache.geode.internal.logging.LogService;
+import org.apache.geode.internal.logging.LogWriterFactory;
+import org.apache.geode.internal.logging.log4j.LocalizedMessage;
+import org.apache.geode.internal.logging.log4j.LogMarker;
+import org.apache.geode.internal.logging.log4j.LogWriterAppender;
+import org.apache.geode.internal.logging.log4j.LogWriterAppenders;
+import org.apache.geode.internal.util.concurrent.FutureResult;
 import org.apache.logging.log4j.Logger;
 
 import java.io.File;
@@ -49,7 +49,7 @@ import java.text.SimpleDateFormat;
 import java.util.*;
 import java.util.concurrent.*;
 
-import static com.gemstone.gemfire.distributed.ConfigurationProperties.*;
+import static org.apache.geode.distributed.ConfigurationProperties.*;
 
 /**
  * Represents a GemFire distributed system for remote administration/management.
@@ -57,10 +57,10 @@ import static com.gemstone.gemfire.distributed.ConfigurationProperties.*;
  * @since GemFire     3.5
  */
 public class AdminDistributedSystemImpl
-implements com.gemstone.gemfire.admin.AdminDistributedSystem,
-           com.gemstone.gemfire.internal.admin.JoinLeaveListener,
-           com.gemstone.gemfire.internal.admin.AlertListener,
-           com.gemstone.gemfire.distributed.internal.InternalDistributedSystem.DisconnectListener {
+implements org.apache.geode.admin.AdminDistributedSystem,
+           org.apache.geode.internal.admin.JoinLeaveListener,
+           org.apache.geode.internal.admin.AlertListener,
+           org.apache.geode.distributed.internal.InternalDistributedSystem.DisconnectListener {
 
   private static final Logger logger = LogService.getLogger();
   
@@ -200,7 +200,7 @@ implements com.gemstone.gemfire.admin.AdminDistributedSystem,
   
   /**
    * Creates DistributionLocator instances for every locator entry in the
-   * {@link com.gemstone.gemfire.admin.DistributedSystemConfig}
+   * {@link org.apache.geode.admin.DistributedSystemConfig}
    */
   private void initializeDistributionLocators() {
     DistributionLocatorConfig[] configs =
@@ -224,7 +224,7 @@ implements com.gemstone.gemfire.admin.AdminDistributedSystem,
   /**
    * Creates <code>CacheServer</code> instances for every cache server
    * entry in the {@link
-   * com.gemstone.gemfire.admin.DistributedSystemConfig}
+   * org.apache.geode.admin.DistributedSystemConfig}
    */
   private void initializeCacheServers() {
     CacheServerConfig[] cacheServerConfigs =
@@ -616,7 +616,7 @@ implements com.gemstone.gemfire.admin.AdminDistributedSystem,
    * @return array of system members for each non-manager member
    */
   public SystemMember[] getSystemMemberApplications()
-  throws com.gemstone.gemfire.admin.AdminException {
+  throws org.apache.geode.admin.AdminException {
     synchronized(this.applicationSet) {
       Collection coll = new ArrayList(this.applicationSet.size());
       APPS: for (Iterator iter = this.applicationSet.iterator();
@@ -682,7 +682,7 @@ implements com.gemstone.gemfire.admin.AdminDistributedSystem,
    * <p>
    *
    * See {@link
-   * com.gemstone.gemfire.distributed.DistributedSystem#connect} for a
+   * org.apache.geode.distributed.DistributedSystem#connect} for a
    * list of exceptions that may be thrown.
    *
    * @param logWriter the InternalLogWriter to use for any logging
@@ -864,7 +864,7 @@ implements com.gemstone.gemfire.admin.AdminDistributedSystem,
   /** 
    * Closes all connections and resources to the connected distributed system.
    *
-   * @see com.gemstone.gemfire.distributed.DistributedSystem#disconnect()
+   * @see org.apache.geode.distributed.DistributedSystem#disconnect()
    */
   public void disconnect() {
     synchronized (CONNECTION_SYNC) {
@@ -1035,7 +1035,7 @@ implements com.gemstone.gemfire.admin.AdminDistributedSystem,
   /** sync to prevent bug 33341 Admin API can double-represent system members */
   private final Object membershipListenerLock = new Object();
   
-  // --------- com.gemstone.gemfire.internal.admin.JoinLeaveListener ---------
+  // --------- org.apache.geode.internal.admin.JoinLeaveListener ---------
   /** 
    * Listener callback for when a member has joined this DistributedSystem.
    * <p>
@@ -1046,7 +1046,7 @@ implements com.gemstone.gemfire.admin.AdminDistributedSystem,
    *
    * @param source  the distributed system that fired nodeJoined
    * @param vm  the VM that joined
-   * @see com.gemstone.gemfire.internal.admin.JoinLeaveListener#nodeJoined
+   * @see org.apache.geode.internal.admin.JoinLeaveListener#nodeJoined
    */
   public void nodeJoined(GfManagerAgent source, final GemFireVM vm) {
     // sync to prevent bug 33341 Admin API can double-represent system members
@@ -1151,7 +1151,7 @@ implements com.gemstone.gemfire.admin.AdminDistributedSystem,
    *
    * @param source  the distributed system that fired nodeCrashed
    * @param vm    the VM that left
-   * @see com.gemstone.gemfire.internal.admin.JoinLeaveListener#nodeLeft
+   * @see org.apache.geode.internal.admin.JoinLeaveListener#nodeLeft
    */
   public void nodeLeft(GfManagerAgent source, GemFireVM vm) {
     // sync to prevent bug 33341 Admin API can double-represent system members
@@ -1182,7 +1182,7 @@ implements com.gemstone.gemfire.admin.AdminDistributedSystem,
    *
    * @param source  the distributed system that fired nodeCrashed
    * @param vm the VM that crashed
-   * @see com.gemstone.gemfire.internal.admin.JoinLeaveListener#nodeCrashed
+   * @see org.apache.geode.internal.admin.JoinLeaveListener#nodeCrashed
    */
   public void nodeCrashed(GfManagerAgent source, GemFireVM vm) {
     // sync to prevent bug 33341 Admin API can double-represent system members
@@ -1207,15 +1207,15 @@ implements com.gemstone.gemfire.admin.AdminDistributedSystem,
     }
   }
 
-  // ----------- com.gemstone.gemfire.internal.admin.AlertListener -----------
+  // ----------- org.apache.geode.internal.admin.AlertListener -----------
   /** 
    * Listener callback for when a SystemMember of this DistributedSystem has 
    * crashed. 
    *
    * @param alert   the latest alert from the system
-   * @see com.gemstone.gemfire.internal.admin.AlertListener#alert
+   * @see org.apache.geode.internal.admin.AlertListener#alert
    */
-  public void alert(com.gemstone.gemfire.internal.admin.Alert alert) {
+  public void alert(org.apache.geode.internal.admin.Alert alert) {
     if (AlertLevel.forSeverity(alert.getLevel()).ordinal < alertLevel.ordinal) {
       return;
     }
@@ -1255,7 +1255,7 @@ implements com.gemstone.gemfire.admin.AdminDistributedSystem,
    *  @throws AdminException TODO-javadocs
    */
   protected SystemMember createSystemMember(ApplicationVM app)
-  throws com.gemstone.gemfire.admin.AdminException {
+  throws org.apache.geode.admin.AdminException {
     return new SystemMemberImpl(this, app);
   }
 
@@ -1267,12 +1267,12 @@ implements com.gemstone.gemfire.admin.AdminDistributedSystem,
    *          InternalDistributedMember instance for which a SystemMember
    *          instance is to be constructed.
    * @return constructed SystemMember instance
-   * @throws com.gemstone.gemfire.admin.AdminException
+   * @throws org.apache.geode.admin.AdminException
    *           if construction of SystemMember instance fails
    * @since GemFire 6.5
    */
   protected SystemMember createSystemMember(InternalDistributedMember member)
-    throws com.gemstone.gemfire.admin.AdminException {
+    throws org.apache.geode.admin.AdminException {
     return new SystemMemberImpl(this, member);
   }
 
@@ -2099,7 +2099,7 @@ implements com.gemstone.gemfire.admin.AdminDistributedSystem,
    */
   public class AlertImpl implements Alert {
     /** The Alert to which most behavior is delegated */
-    private final com.gemstone.gemfire.internal.admin.Alert alert;
+    private final org.apache.geode.internal.admin.Alert alert;
     private SystemMember systemMember;
 
     ///////////////////////  Constructors  ///////////////////////
@@ -2108,7 +2108,7 @@ implements com.gemstone.gemfire.admin.AdminDistributedSystem,
      * Creates a new <code>Alert</code> that delegates to the given
      * object. 
      */
-    AlertImpl(com.gemstone.gemfire.internal.admin.Alert alert) {
+    AlertImpl(org.apache.geode.internal.admin.Alert alert) {
       this.alert   = alert;
       GemFireVM vm = alert.getGemFireVM();
 

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/admin/internal/BackupDataStoreHelper.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/admin/internal/BackupDataStoreHelper.java b/geode-core/src/main/java/org/apache/geode/admin/internal/BackupDataStoreHelper.java
index 58a66bc..0d68f02 100644
--- a/geode-core/src/main/java/org/apache/geode/admin/internal/BackupDataStoreHelper.java
+++ b/geode-core/src/main/java/org/apache/geode/admin/internal/BackupDataStoreHelper.java
@@ -14,17 +14,17 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.admin.internal;
+package org.apache.geode.admin.internal;
 
 import java.io.File;
 import java.util.Map;
 import java.util.Set;
 
-import com.gemstone.gemfire.cache.persistence.PersistentID;
-import com.gemstone.gemfire.distributed.DistributedLockService;
-import com.gemstone.gemfire.distributed.DistributedMember;
-import com.gemstone.gemfire.distributed.internal.DM;
-import com.gemstone.gemfire.internal.Assert;
+import org.apache.geode.cache.persistence.PersistentID;
+import org.apache.geode.distributed.DistributedLockService;
+import org.apache.geode.distributed.DistributedMember;
+import org.apache.geode.distributed.internal.DM;
+import org.apache.geode.internal.Assert;
 
 public class BackupDataStoreHelper {
 

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/admin/internal/BackupDataStoreResult.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/admin/internal/BackupDataStoreResult.java b/geode-core/src/main/java/org/apache/geode/admin/internal/BackupDataStoreResult.java
index b939f75..b2a201d 100644
--- a/geode-core/src/main/java/org/apache/geode/admin/internal/BackupDataStoreResult.java
+++ b/geode-core/src/main/java/org/apache/geode/admin/internal/BackupDataStoreResult.java
@@ -14,13 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.admin.internal;
+package org.apache.geode.admin.internal;
 
 import java.util.Map;
 import java.util.Set;
 
-import com.gemstone.gemfire.cache.persistence.PersistentID;
-import com.gemstone.gemfire.distributed.DistributedMember;
+import org.apache.geode.cache.persistence.PersistentID;
+import org.apache.geode.distributed.DistributedMember;
 
 public class BackupDataStoreResult {
   

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/admin/internal/BackupStatusImpl.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/admin/internal/BackupStatusImpl.java b/geode-core/src/main/java/org/apache/geode/admin/internal/BackupStatusImpl.java
index 33faed0..074ecb3 100644
--- a/geode-core/src/main/java/org/apache/geode/admin/internal/BackupStatusImpl.java
+++ b/geode-core/src/main/java/org/apache/geode/admin/internal/BackupStatusImpl.java
@@ -14,15 +14,15 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.admin.internal;
+package org.apache.geode.admin.internal;
 
 import java.io.Serializable;
 import java.util.Map;
 import java.util.Set;
 
-import com.gemstone.gemfire.admin.BackupStatus;
-import com.gemstone.gemfire.cache.persistence.PersistentID;
-import com.gemstone.gemfire.distributed.DistributedMember;
+import org.apache.geode.admin.BackupStatus;
+import org.apache.geode.cache.persistence.PersistentID;
+import org.apache.geode.distributed.DistributedMember;
 
 /**
  * Holds the result of a backup operation.

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/admin/internal/CacheHealthConfigImpl.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/admin/internal/CacheHealthConfigImpl.java b/geode-core/src/main/java/org/apache/geode/admin/internal/CacheHealthConfigImpl.java
index 59be648..fd82b24 100644
--- a/geode-core/src/main/java/org/apache/geode/admin/internal/CacheHealthConfigImpl.java
+++ b/geode-core/src/main/java/org/apache/geode/admin/internal/CacheHealthConfigImpl.java
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.admin.internal;
+package org.apache.geode.admin.internal;
 
-import com.gemstone.gemfire.admin.*;
+import org.apache.geode.admin.*;
 
 /**
  * The implementation of <code>CacheHealthConfig</code>

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/admin/internal/CacheHealthEvaluator.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/admin/internal/CacheHealthEvaluator.java b/geode-core/src/main/java/org/apache/geode/admin/internal/CacheHealthEvaluator.java
index 67f39f7..6ab9f34 100644
--- a/geode-core/src/main/java/org/apache/geode/admin/internal/CacheHealthEvaluator.java
+++ b/geode-core/src/main/java/org/apache/geode/admin/internal/CacheHealthEvaluator.java
@@ -14,24 +14,24 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.admin.internal;
+package org.apache.geode.admin.internal;
 
 import java.util.List;
 
 import org.apache.logging.log4j.Logger;
 
-import com.gemstone.gemfire.CancelException;
-import com.gemstone.gemfire.admin.CacheHealthConfig;
-import com.gemstone.gemfire.admin.GemFireHealthConfig;
-import com.gemstone.gemfire.cache.CacheFactory;
-import com.gemstone.gemfire.distributed.internal.DM;
-import com.gemstone.gemfire.distributed.internal.InternalDistributedSystem;
-import com.gemstone.gemfire.internal.OSProcess;
-import com.gemstone.gemfire.internal.cache.CacheLifecycleListener;
-import com.gemstone.gemfire.internal.cache.CachePerfStats;
-import com.gemstone.gemfire.internal.cache.GemFireCacheImpl;
-import com.gemstone.gemfire.internal.i18n.LocalizedStrings;
-import com.gemstone.gemfire.internal.logging.LogService;
+import org.apache.geode.CancelException;
+import org.apache.geode.admin.CacheHealthConfig;
+import org.apache.geode.admin.GemFireHealthConfig;
+import org.apache.geode.cache.CacheFactory;
+import org.apache.geode.distributed.internal.DM;
+import org.apache.geode.distributed.internal.InternalDistributedSystem;
+import org.apache.geode.internal.OSProcess;
+import org.apache.geode.internal.cache.CacheLifecycleListener;
+import org.apache.geode.internal.cache.CachePerfStats;
+import org.apache.geode.internal.cache.GemFireCacheImpl;
+import org.apache.geode.internal.i18n.LocalizedStrings;
+import org.apache.geode.internal.logging.LogService;
 
 /**
  * Contains the logic for evaluating the health of a GemFire

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/admin/internal/CacheServerConfigImpl.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/admin/internal/CacheServerConfigImpl.java b/geode-core/src/main/java/org/apache/geode/admin/internal/CacheServerConfigImpl.java
index eb5b646..e34a476 100644
--- a/geode-core/src/main/java/org/apache/geode/admin/internal/CacheServerConfigImpl.java
+++ b/geode-core/src/main/java/org/apache/geode/admin/internal/CacheServerConfigImpl.java
@@ -14,13 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.admin.internal;
+package org.apache.geode.admin.internal;
 
-import com.gemstone.gemfire.admin.CacheServerConfig;
-import com.gemstone.gemfire.admin.CacheVmConfig;
-import com.gemstone.gemfire.internal.admin.GemFireVM;
+import org.apache.geode.admin.CacheServerConfig;
+import org.apache.geode.admin.CacheVmConfig;
+import org.apache.geode.internal.admin.GemFireVM;
 
-import static com.gemstone.gemfire.distributed.ConfigurationProperties.*;
+import static org.apache.geode.distributed.ConfigurationProperties.*;
 
 /**
  * An implementation of <code>CacheVmConfig</code>

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/admin/internal/CacheServerImpl.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/admin/internal/CacheServerImpl.java b/geode-core/src/main/java/org/apache/geode/admin/internal/CacheServerImpl.java
index 325c943..f13c9ba 100644
--- a/geode-core/src/main/java/org/apache/geode/admin/internal/CacheServerImpl.java
+++ b/geode-core/src/main/java/org/apache/geode/admin/internal/CacheServerImpl.java
@@ -14,15 +14,15 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.admin.internal;
+package org.apache.geode.admin.internal;
 
-import com.gemstone.gemfire.admin.*;
-import com.gemstone.gemfire.distributed.internal.DM;
-import com.gemstone.gemfire.distributed.internal.DistributionManager;
-import com.gemstone.gemfire.internal.admin.GemFireVM;
-import com.gemstone.gemfire.internal.admin.remote.RemoteApplicationVM;
+import org.apache.geode.admin.*;
+import org.apache.geode.distributed.internal.DM;
+import org.apache.geode.distributed.internal.DistributionManager;
+import org.apache.geode.internal.admin.GemFireVM;
+import org.apache.geode.internal.admin.remote.RemoteApplicationVM;
 
-import static com.gemstone.gemfire.distributed.ConfigurationProperties.*;
+import static org.apache.geode.distributed.ConfigurationProperties.*;
 
 /**
  * Implements the administrative interface to a cache server.

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/admin/internal/ConfigurationParameterImpl.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/admin/internal/ConfigurationParameterImpl.java b/geode-core/src/main/java/org/apache/geode/admin/internal/ConfigurationParameterImpl.java
index a6f86c5..e556b04 100755
--- a/geode-core/src/main/java/org/apache/geode/admin/internal/ConfigurationParameterImpl.java
+++ b/geode-core/src/main/java/org/apache/geode/admin/internal/ConfigurationParameterImpl.java
@@ -15,11 +15,11 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.admin.internal;
+package org.apache.geode.admin.internal;
 
-import com.gemstone.gemfire.admin.ConfigurationParameter;
-import com.gemstone.gemfire.admin.UnmodifiableConfigurationException;
-import com.gemstone.gemfire.internal.i18n.LocalizedStrings;
+import org.apache.geode.admin.ConfigurationParameter;
+import org.apache.geode.admin.UnmodifiableConfigurationException;
+import org.apache.geode.internal.i18n.LocalizedStrings;
 
 import java.io.File;
 //import java.net.InetAddress;
@@ -34,7 +34,7 @@ import java.util.List;
  *
  */
 public class ConfigurationParameterImpl
-implements com.gemstone.gemfire.admin.ConfigurationParameter {
+implements org.apache.geode.admin.ConfigurationParameter {
   
   /** Identifying name of this configuration parameter */
   protected String name;

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/admin/internal/ConfigurationParameterListener.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/admin/internal/DisabledManagedEntityController.java b/geode-core/src/main/java/org/apache/geode/admin/internal/DisabledManagedEntityController.java
index 709af32..8450991 100755
--- a/geode-core/src/main/java/org/apache/geode/admin/internal/DisabledManagedEntityController.java
+++ b/geode-core/src/main/java/org/apache/geode/admin/internal/DisabledManagedEntityController.java
@@ -14,13 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.admin.internal;
+package org.apache.geode.admin.internal;
 
 import org.apache.logging.log4j.Logger;
 
-import com.gemstone.gemfire.admin.DistributedSystemConfig;
-import com.gemstone.gemfire.internal.logging.LogService;
-import com.gemstone.gemfire.internal.logging.log4j.LogMarker;
+import org.apache.geode.admin.DistributedSystemConfig;
+import org.apache.geode.internal.logging.LogService;
+import org.apache.geode.internal.logging.log4j.LogMarker;
 
 /**
  * This is a disabled implementation of ManagedEntityController for bug #47909.

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/admin/internal/DistributedSystemConfigImpl.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/admin/internal/DistributedSystemConfigImpl.java b/geode-core/src/main/java/org/apache/geode/admin/internal/DistributedSystemConfigImpl.java
index 37cd139..6b313e2 100755
--- a/geode-core/src/main/java/org/apache/geode/admin/internal/DistributedSystemConfigImpl.java
+++ b/geode-core/src/main/java/org/apache/geode/admin/internal/DistributedSystemConfigImpl.java
@@ -14,16 +14,16 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.admin.internal;
-
-import com.gemstone.gemfire.admin.*;
-import com.gemstone.gemfire.distributed.internal.DistributionConfig;
-import com.gemstone.gemfire.distributed.internal.DistributionConfigImpl;
-import com.gemstone.gemfire.internal.i18n.LocalizedStrings;
-import com.gemstone.gemfire.internal.logging.InternalLogWriter;
-import com.gemstone.gemfire.internal.logging.LogConfig;
-import com.gemstone.gemfire.internal.logging.LogService;
-import com.gemstone.gemfire.internal.logging.LogWriterImpl;
+package org.apache.geode.admin.internal;
+
+import org.apache.geode.admin.*;
+import org.apache.geode.distributed.internal.DistributionConfig;
+import org.apache.geode.distributed.internal.DistributionConfigImpl;
+import org.apache.geode.internal.i18n.LocalizedStrings;
+import org.apache.geode.internal.logging.InternalLogWriter;
+import org.apache.geode.internal.logging.LogConfig;
+import org.apache.geode.internal.logging.LogService;
+import org.apache.geode.internal.logging.LogWriterImpl;
 import org.apache.logging.log4j.Logger;
 
 import java.io.File;
@@ -32,7 +32,7 @@ import java.io.IOException;
 import java.io.InputStream;
 import java.util.*;
 
-import static com.gemstone.gemfire.distributed.ConfigurationProperties.*;
+import static org.apache.geode.distributed.ConfigurationProperties.*;
 
 /**
  * An implementation of the configuration object for an

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/admin/internal/DistributedSystemHealthConfigImpl.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/admin/internal/DistributedSystemHealthConfigImpl.java b/geode-core/src/main/java/org/apache/geode/admin/internal/DistributedSystemHealthConfigImpl.java
index 25ee3e3..b7a2057 100644
--- a/geode-core/src/main/java/org/apache/geode/admin/internal/DistributedSystemHealthConfigImpl.java
+++ b/geode-core/src/main/java/org/apache/geode/admin/internal/DistributedSystemHealthConfigImpl.java
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.admin.internal;
+package org.apache.geode.admin.internal;
 
-import com.gemstone.gemfire.admin.*;
+import org.apache.geode.admin.*;
 
 /**
  * The implementation of <code>DistributedSystemHealthConfig</code>.

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/admin/internal/DistributedSystemHealthEvaluator.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/admin/internal/DistributedSystemHealthEvaluator.java b/geode-core/src/main/java/org/apache/geode/admin/internal/DistributedSystemHealthEvaluator.java
index 33989a8..287de7f 100644
--- a/geode-core/src/main/java/org/apache/geode/admin/internal/DistributedSystemHealthEvaluator.java
+++ b/geode-core/src/main/java/org/apache/geode/admin/internal/DistributedSystemHealthEvaluator.java
@@ -14,15 +14,15 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.admin.internal;
-
-import com.gemstone.gemfire.admin.DistributedSystemHealthConfig;
-import com.gemstone.gemfire.distributed.internal.DM;
-import com.gemstone.gemfire.distributed.internal.DistributionConfig;
-import com.gemstone.gemfire.distributed.internal.DistributionManager;
-import com.gemstone.gemfire.distributed.internal.MembershipListener;
-import com.gemstone.gemfire.distributed.internal.membership.InternalDistributedMember;
-import com.gemstone.gemfire.internal.i18n.LocalizedStrings;
+package org.apache.geode.admin.internal;
+
+import org.apache.geode.admin.DistributedSystemHealthConfig;
+import org.apache.geode.distributed.internal.DM;
+import org.apache.geode.distributed.internal.DistributionConfig;
+import org.apache.geode.distributed.internal.DistributionManager;
+import org.apache.geode.distributed.internal.MembershipListener;
+import org.apache.geode.distributed.internal.membership.InternalDistributedMember;
+import org.apache.geode.internal.i18n.LocalizedStrings;
 
 import java.util.List;
 import java.util.Set;

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/admin/internal/DistributedSystemHealthMonitor.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/admin/internal/DistributedSystemHealthMonitor.java b/geode-core/src/main/java/org/apache/geode/admin/internal/DistributedSystemHealthMonitor.java
index afb3335..652a57c 100644
--- a/geode-core/src/main/java/org/apache/geode/admin/internal/DistributedSystemHealthMonitor.java
+++ b/geode-core/src/main/java/org/apache/geode/admin/internal/DistributedSystemHealthMonitor.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.admin.internal;
+package org.apache.geode.admin.internal;
 
 import java.util.ArrayList;
 import java.util.Iterator;
@@ -23,37 +23,37 @@ import java.util.Properties;
 
 import org.apache.logging.log4j.Logger;
 
-import com.gemstone.gemfire.SystemFailure;
-import com.gemstone.gemfire.admin.AdminException;
-import com.gemstone.gemfire.admin.GemFireHealth;
-import com.gemstone.gemfire.admin.GemFireHealthConfig;
-import com.gemstone.gemfire.admin.GemFireMemberStatus;
-import com.gemstone.gemfire.admin.RegionSubRegionSnapshot;
-import com.gemstone.gemfire.cache.Region;
-import com.gemstone.gemfire.cache.RegionAttributes;
-import com.gemstone.gemfire.distributed.internal.membership.InternalDistributedMember;
-import com.gemstone.gemfire.internal.Assert;
-import com.gemstone.gemfire.internal.Config;
-import com.gemstone.gemfire.internal.net.SocketCreator;
-import com.gemstone.gemfire.internal.admin.AdminBridgeServer;
-import com.gemstone.gemfire.internal.admin.CacheInfo;
-import com.gemstone.gemfire.internal.admin.DLockInfo;
-import com.gemstone.gemfire.internal.admin.GemFireVM;
-import com.gemstone.gemfire.internal.admin.GfManagerAgent;
-import com.gemstone.gemfire.internal.admin.HealthListener;
-import com.gemstone.gemfire.internal.admin.Stat;
-import com.gemstone.gemfire.internal.admin.StatAlertDefinition;
-import com.gemstone.gemfire.internal.admin.StatListener;
-import com.gemstone.gemfire.internal.admin.StatResource;
-import com.gemstone.gemfire.internal.i18n.LocalizedStrings;
-import com.gemstone.gemfire.internal.logging.LogService;
-import com.gemstone.gemfire.internal.logging.LoggingThreadGroup;
-import com.gemstone.gemfire.internal.logging.log4j.LocalizedMessage;
+import org.apache.geode.SystemFailure;
+import org.apache.geode.admin.AdminException;
+import org.apache.geode.admin.GemFireHealth;
+import org.apache.geode.admin.GemFireHealthConfig;
+import org.apache.geode.admin.GemFireMemberStatus;
+import org.apache.geode.admin.RegionSubRegionSnapshot;
+import org.apache.geode.cache.Region;
+import org.apache.geode.cache.RegionAttributes;
+import org.apache.geode.distributed.internal.membership.InternalDistributedMember;
+import org.apache.geode.internal.Assert;
+import org.apache.geode.internal.Config;
+import org.apache.geode.internal.net.SocketCreator;
+import org.apache.geode.internal.admin.AdminBridgeServer;
+import org.apache.geode.internal.admin.CacheInfo;
+import org.apache.geode.internal.admin.DLockInfo;
+import org.apache.geode.internal.admin.GemFireVM;
+import org.apache.geode.internal.admin.GfManagerAgent;
+import org.apache.geode.internal.admin.HealthListener;
+import org.apache.geode.internal.admin.Stat;
+import org.apache.geode.internal.admin.StatAlertDefinition;
+import org.apache.geode.internal.admin.StatListener;
+import org.apache.geode.internal.admin.StatResource;
+import org.apache.geode.internal.i18n.LocalizedStrings;
+import org.apache.geode.internal.logging.LogService;
+import org.apache.geode.internal.logging.LoggingThreadGroup;
+import org.apache.geode.internal.logging.log4j.LocalizedMessage;
 
 /**
  * A thread that monitors the health of the distributed system.  It is
  * kind of like a {@link
- * com.gemstone.gemfire.distributed.internal.HealthMonitorImpl}.  In
+ * org.apache.geode.distributed.internal.HealthMonitorImpl}.  In
  * order to get it to place nice with the rest of the health
  * monitoring APIs, this class pretends that it is a
  * <code>GemFireVM</code>.  Kind of hokey, but it beats a bunch of
@@ -218,7 +218,7 @@ class DistributedSystemHealthMonitor implements Runnable, GemFireVM {
       return SocketCreator.getLocalHost();
 
     } catch (Exception ex) {
-      throw new com.gemstone.gemfire.InternalGemFireException(LocalizedStrings.DistributedSystemHealthMonitor_COULD_NOT_GET_LOCALHOST.toLocalizedString());
+      throw new org.apache.geode.InternalGemFireException(LocalizedStrings.DistributedSystemHealthMonitor_COULD_NOT_GET_LOCALHOST.toLocalizedString());
     }
   }
diff --git a/geode-core/src/main/java/org/apache/geode/admin/DistributedSystemConfig.java b/geode-core/src/main/java/org/apache/geode/admin/DistributedSystemConfig.java
index 17600bc..67f8c7c 100755
--- a/geode-core/src/main/java/org/apache/geode/admin/DistributedSystemConfig.java
+++ b/geode-core/src/main/java/org/apache/geode/admin/DistributedSystemConfig.java
@@ -14,14 +14,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.admin;
+package org.apache.geode.admin;
 
-import com.gemstone.gemfire.admin.internal.InetAddressUtil;
-import com.gemstone.gemfire.distributed.internal.DistributionConfig;
+import org.apache.geode.admin.internal.InetAddressUtil;
+import org.apache.geode.distributed.internal.DistributionConfig;
 
 import java.util.Properties;
 
-import static com.gemstone.gemfire.distributed.ConfigurationProperties.*;
+import static org.apache.geode.distributed.ConfigurationProperties.*;
 
 
 /**
@@ -37,7 +37,7 @@ import static com.gemstone.gemfire.distributed.ConfigurationProperties.*;
  *
  * Detailed descriptions of many of these configuration attributes can
  * be found in the {@link
- * com.gemstone.gemfire.distributed.DistributedSystem
+ * org.apache.geode.distributed.DistributedSystem
  * DistributedSystem} class.  Note that the default values of these
  * configuration attributes can be specified using Java system
  * properties.
@@ -57,7 +57,7 @@ import static com.gemstone.gemfire.distributed.ConfigurationProperties.*;
  * the {@link #clone} method.
  *
  * @since GemFire 3.5
  * @deprecated as of 7.0 use the <code><a href="{@docRoot}/com/gemstone/gemfire/management/package-summary.html">management</a></code> package instead
 */
 public interface DistributedSystemConfig extends Cloneable {
 
@@ -267,7 +267,7 @@ public interface DistributedSystemConfig extends Cloneable {
 
   /**
    * Returns the name of the XML file that specifies the configuration
    * of the {@linkplain com.gemstone.gemfire.admin.ManagedEntity
    * managed entities} administered by the
    * <code>DistributedSystem</code>.  The XML file must conform to a
    * <a href="doc-files/ds5_0.dtd">dtd</a>.
@@ -483,7 +483,7 @@ public interface DistributedSystemConfig extends Cloneable {
    * Returns the name of the log file to which informational messages
    * are written.
    *
-   * @see com.gemstone.gemfire.i18n.LogWriterI18n
+   * @see org.apache.geode.i18n.LogWriterI18n
    */
   public String getLogFile();
 
@@ -491,7 +491,7 @@ public interface DistributedSystemConfig extends Cloneable {
    * Sets the name of the log file to which informational messages
    * are written.
    *
-   * @see com.gemstone.gemfire.i18n.LogWriterI18n
+   * @see org.apache.geode.i18n.LogWriterI18n
    */
   public void setLogFile(String logFile);
 

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/admin/DistributedSystemHealthConfig.java
----------------------------------------------------------------------
@@ -57,7 +57,7 @@ import static com.gemstone.gemfire.distributed.ConfigurationProperties.*;
  *
  * @since GemFire 3.5
- * @deprecated as of 7.0 use the <code><a href="{@docRoot}/com/gemstone/gemfire/management/package-summary.html">management</a></code> package instead
+ * @deprecated as of 7.0 use the <code><a href="{@docRoot}/org/apache/geode/management/package-summary.html">management</a></code> package instead
 */
 public interface DistributedSystemConfig extends Cloneable {
@@ -267,7 +267,7 @@ public interface DistributedSystemConfig extends Cloneable {
   /**
    * Returns the name of the XML file that specifies the configuration
-   * of the {@linkplain com.gemstone.gemfire.admin.ManagedEntity
+   * of the {@linkplain org.apache.geode.admin.ManagedEntity
    * managed entities} administered by the
    * <code>DistributedSystem</code>.  The XML file must conform to a
diff --git a/geode-core/src/main/java/org/apache/geode/admin/DistributedSystemHealthConfig.java b/geode-core/src/main/java/org/apache/geode/admin/DistributedSystemHealthConfig.java
index 5ece6cd..d9416ce 100644
--- a/geode-core/src/main/java/org/apache/geode/admin/DistributedSystemHealthConfig.java
+++ b/geode-core/src/main/java/org/apache/geode/admin/DistributedSystemHealthConfig.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.admin;
+package org.apache.geode.admin;
 
 /**
  * Provides configuration information relating to the health of an
@@ -48,7 +48,7 @@ package com.gemstone.gemfire.admin;
  *
  *
  * @since GemFire 3.5
  * @deprecated as of 7.0 use the <code><a href="{@docRoot}/com/gemstone/gemfire/management/package-summary.html">management</a></code> package instead
  * */
 public interface DistributedSystemHealthConfig {
 

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/admin/DistributionLocator.java
----------------------------------------------------------------------
@@ -48,7 +48,7 @@ package com.gemstone.gemfire.admin;
  *
  * @since GemFire 3.5
- * @deprecated as of 7.0 use the <code><a href="{@docRoot}/com/gemstone/gemfire/management/package-summary.html">management</a></code> package instead
+ * @deprecated as of 7.0 use the <code><a href="{@docRoot}/org/apache/geode/management/package-summary.html">management</a></code> package instead
  * */
 public interface DistributedSystemHealthConfig {
diff --git a/geode-core/src/main/java/org/apache/geode/admin/DistributionLocator.java b/geode-core/src/main/java/org/apache/geode/admin/DistributionLocator.java
index 541a3e2..da8864c 100755
--- a/geode-core/src/main/java/org/apache/geode/admin/DistributionLocator.java
+++ b/geode-core/src/main/java/org/apache/geode/admin/DistributionLocator.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.admin;
+package org.apache.geode.admin;
 
 /**
  * Represents a single distribution locator server, of which a
@@ -26,7 +26,7 @@ package com.gemstone.gemfire.admin;
  * @see DistributionLocatorConfig
  *
  * @since GemFire 3.5
  * @deprecated as of 7.0 use the <code><a href="{@docRoot}/com/gemstone/gemfire/management/package-summary.html">management</a></code> package instead
  */
 public interface DistributionLocator extends ManagedEntity {
   

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/admin/DistributionLocatorConfig.java
----------------------------------------------------------------------
@@ -26,7 +26,7 @@ package com.gemstone.gemfire.admin;
  *
  * @since GemFire 3.5
- * @deprecated as of 7.0 use the <code><a href="{@docRoot}/com/gemstone/gemfire/management/package-summary.html">management</a></code> package instead
+ * @deprecated as of 7.0 use the <code><a href="{@docRoot}/org/apache/geode/management/package-summary.html">management</a></code> package instead
  */
 public interface DistributionLocator extends ManagedEntity {
diff --git a/geode-core/src/main/java/org/apache/geode/admin/DistributionLocatorConfig.java b/geode-core/src/main/java/org/apache/geode/admin/DistributionLocatorConfig.java
index 8c6770c..162f4f1 100644
--- a/geode-core/src/main/java/org/apache/geode/admin/DistributionLocatorConfig.java
+++ b/geode-core/src/main/java/org/apache/geode/admin/DistributionLocatorConfig.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.admin;
+package org.apache.geode.admin;
 import java.util.Properties;
 
 /**
@@ -36,10 +36,10 @@ import java.util.Properties;
  * invoking the {@link Object#clone} method.
  *
  * @see AdminDistributedSystem#addDistributionLocator
- * @see com.gemstone.gemfire.distributed.Locator
+ * @see org.apache.geode.distributed.Locator
  *
  * @since GemFire 4.0
  * @deprecated as of 7.0 use the <code><a href="{@docRoot}/com/gemstone/gemfire/management/package-summary.html">management</a></code> package instead
  */
 public interface DistributionLocatorConfig
   extends ManagedEntityConfig {

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/admin/GemFireHealth.java
----------------------------------------------------------------------
@@ -36,10 +36,10 @@ import java.util.Properties;
  *
  * @since GemFire 4.0
- * @deprecated as of 7.0 use the <code><a href="{@docRoot}/com/gemstone/gemfire/management/package-summary.html">management</a></code> package instead
+ * @deprecated as of 7.0 use the <code><a href="{@docRoot}/org/apache/geode/management/package-summary.html">management</a></code> package instead
  */
 public interface DistributionLocatorConfig
diff --git a/geode-core/src/main/java/org/apache/geode/admin/GemFireHealth.java b/geode-core/src/main/java/org/apache/geode/admin/GemFireHealth.java
index 7665cbf..202ce70 100644
--- a/geode-core/src/main/java/org/apache/geode/admin/GemFireHealth.java
+++ b/geode-core/src/main/java/org/apache/geode/admin/GemFireHealth.java
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.admin;
+package org.apache.geode.admin;
 
-import com.gemstone.gemfire.internal.Assert;
-import com.gemstone.gemfire.internal.i18n.LocalizedStrings;
+import org.apache.geode.internal.Assert;
+import org.apache.geode.internal.i18n.LocalizedStrings;
 
 /**
  * Provides information about the aggregate health of the members of a
@@ -42,7 +42,7 @@ import com.gemstone.gemfire.internal.i18n.LocalizedStrings;
  *
  *
  * @since GemFire 3.5
  * @deprecated as of 7.0 use the <code><a href="{@docRoot}/com/gemstone/gemfire/management/package-summary.html">management</a></code> package instead
  * */
 public interface GemFireHealth {
 

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/admin/GemFireHealthConfig.java
----------------------------------------------------------------------
@@ -42,7 +42,7 @@ import com.gemstone.gemfire.internal.i18n.LocalizedStrings;
  *
  * @since GemFire 3.5
- * @deprecated as of 7.0 use the <code><a href="{@docRoot}/com/gemstone/gemfire/management/package-summary.html">management</a></code> package instead
+ * @deprecated as of 7.0 use the <code><a href="{@docRoot}/org/apache/geode/management/package-summary.html">management</a></code> package instead
  * */
 public interface GemFireHealth {
diff --git a/geode-core/src/main/java/org/apache/geode/admin/GemFireHealthConfig.java b/geode-core/src/main/java/org/apache/geode/admin/GemFireHealthConfig.java
index d7bc22c..638244a 100644
--- a/geode-core/src/main/java/org/apache/geode/admin/GemFireHealthConfig.java
+++ b/geode-core/src/main/java/org/apache/geode/admin/GemFireHealthConfig.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.admin;
+package org.apache.geode.admin;
 
 /**
  * Provides configuration information relating to all of the
@@ -22,7 +22,7 @@ package com.gemstone.gemfire.admin;
  *
  *
  * @since GemFire 3.5
  * @deprecated as of 7.0 use the <code><a href="{@docRoot}/com/gemstone/gemfire/management/package-summary.html">management</a></code> package instead
  * */
 public interface GemFireHealthConfig
   extends MemberHealthConfig, CacheHealthConfig {

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/admin/GemFireMemberStatus.java
----------------------------------------------------------------------
@@ -22,7 +22,7 @@ package com.gemstone.gemfire.admin;
  *
  * @since GemFire 3.5
- * @deprecated as of 7.0 use the <code><a href="{@docRoot}/com/gemstone/gemfire/management/package-summary.html">management</a></code> package instead
+ * @deprecated as of 7.0 use the <code><a href="{@docRoot}/org/apache/geode/management/package-summary.html">management</a></code> package instead
  * */
 public interface GemFireHealthConfig
diff --git a/geode-core/src/main/java/org/apache/geode/admin/GemFireMemberStatus.java b/geode-core/src/main/java/org/apache/geode/admin/GemFireMemberStatus.java
index 0f1610c..b785125 100755
--- a/geode-core/src/main/java/org/apache/geode/admin/GemFireMemberStatus.java
+++ b/geode-core/src/main/java/org/apache/geode/admin/GemFireMemberStatus.java
@@ -14,24 +14,24 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.admin;
-
-import com.gemstone.gemfire.cache.Cache;
-import com.gemstone.gemfire.cache.Region;
-import com.gemstone.gemfire.cache.client.PoolManager;
-import com.gemstone.gemfire.cache.server.CacheServer;
-import com.gemstone.gemfire.distributed.DistributedSystem;
-import com.gemstone.gemfire.distributed.Locator;
-import com.gemstone.gemfire.distributed.internal.DM;
-import com.gemstone.gemfire.distributed.internal.DistributionConfig;
-import com.gemstone.gemfire.distributed.internal.InternalDistributedSystem;
-import com.gemstone.gemfire.distributed.internal.membership.InternalDistributedMember;
-import com.gemstone.gemfire.internal.net.SocketCreator;
-import com.gemstone.gemfire.internal.admin.ClientHealthMonitoringRegion;
-import com.gemstone.gemfire.internal.admin.remote.ClientHealthStats;
-import com.gemstone.gemfire.internal.cache.*;
-import com.gemstone.gemfire.internal.cache.tier.InternalClientMembership;
-import com.gemstone.gemfire.internal.cache.tier.sockets.ClientProxyMembershipID;
+package org.apache.geode.admin;
+
+import org.apache.geode.cache.Cache;
+import org.apache.geode.cache.Region;
+import org.apache.geode.cache.client.PoolManager;
+import org.apache.geode.cache.server.CacheServer;
+import org.apache.geode.distributed.DistributedSystem;
+import org.apache.geode.distributed.Locator;
+import org.apache.geode.distributed.internal.DM;
+import org.apache.geode.distributed.internal.DistributionConfig;
+import org.apache.geode.distributed.internal.InternalDistributedSystem;
+import org.apache.geode.distributed.internal.membership.InternalDistributedMember;
+import org.apache.geode.internal.net.SocketCreator;
+import org.apache.geode.internal.admin.ClientHealthMonitoringRegion;
+import org.apache.geode.internal.admin.remote.ClientHealthStats;
+import org.apache.geode.internal.cache.*;
+import org.apache.geode.internal.cache.tier.InternalClientMembership;
+import org.apache.geode.internal.cache.tier.sockets.ClientProxyMembershipID;
 
 import java.io.IOException;
 import java.io.Serializable;
@@ -42,7 +42,7 @@ import java.util.*;
  * Class <code>GemFireMemberStatus</code> provides the status of a specific
  * GemFire member VM. This VM can be a peer, a client, a server and/or a
  * gateway.
  * @deprecated as of 7.0 use the <code><a href="{@docRoot}/com/gemstone/gemfire/management/package-summary.html">management</a></code> package instead
  */
 public class GemFireMemberStatus implements Serializable {
   private static final long serialVersionUID = 3389997790525991310L;

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/admin/ManagedEntity.java
----------------------------------------------------------------------
@@ -42,7 +42,7 @@ import java.util.*;
  * GemFire member VM. This VM can be a peer, a client, a server and/or a
  * gateway.
- * @deprecated as of 7.0 use the <code><a href="{@docRoot}/com/gemstone/gemfire/management/package-summary.html">management</a></code> package instead
+ * @deprecated as of 7.0 use the <code><a href="{@docRoot}/org/apache/geode/management/package-summary.html">management</a></code> package instead
  */
 public class GemFireMemberStatus implements Serializable {
diff --git a/geode-core/src/main/java/org/apache/geode/admin/ManagedEntity.java b/geode-core/src/main/java/org/apache/geode/admin/ManagedEntity.java
index d7e5d26..0b4851e 100644
--- a/geode-core/src/main/java/org/apache/geode/admin/ManagedEntity.java
+++ b/geode-core/src/main/java/org/apache/geode/admin/ManagedEntity.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.admin;
+package org.apache.geode.admin;
 
 /**
  * A entity that can be managed with the GemFire administration API.
@@ -22,7 +22,7 @@ package com.gemstone.gemfire.admin;
  * @see ManagedEntityConfig
  *
  * @since GemFire 4.0
  * @deprecated as of 7.0 use the <code><a href="{@docRoot}/com/gemstone/gemfire/management/package-summary.html">management</a></code> package instead
  */
 public interface ManagedEntity {
 

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/admin/ManagedEntityConfig.java
----------------------------------------------------------------------
@@ -22,7 +22,7 @@ package com.gemstone.gemfire.admin;
  *
  * @since GemFire 4.0
- * @deprecated as of 7.0 use the <code><a href="{@docRoot}/com/gemstone/gemfire/management/package-summary.html">management</a></code> package instead
+ * @deprecated as of 7.0 use the <code><a href="{@docRoot}/org/apache/geode/management/package-summary.html">management</a></code> package instead
  */
 public interface ManagedEntity {
diff --git a/geode-core/src/main/java/org/apache/geode/admin/ManagedEntityConfig.java b/geode-core/src/main/java/org/apache/geode/admin/ManagedEntityConfig.java
index e82acdc..9a95b44 100644
--- a/geode-core/src/main/java/org/apache/geode/admin/ManagedEntityConfig.java
+++ b/geode-core/src/main/java/org/apache/geode/admin/ManagedEntityConfig.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.admin;
+package org.apache.geode.admin;
 
 /**
  * Common configuration for all entities that can be managed using the
@@ -26,7 +26,7 @@ package com.gemstone.gemfire.admin;
  * @see ManagedEntity
  *
  * @since GemFire 4.0
  * @deprecated as of 7.0 use the <code><a href="{@docRoot}/com/gemstone/gemfire/management/package-summary.html">management</a></code> package instead
  */
 public interface ManagedEntityConfig extends Cloneable {
 

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/admin/MemberHealthConfig.java
----------------------------------------------------------------------
@@ -26,7 +26,7 @@ package com.gemstone.gemfire.admin;
  *
  * @since GemFire 4.0
- * @deprecated as of 7.0 use the <code><a href="{@docRoot}/com/gemstone/gemfire/management/package-summary.html">management</a></code> package instead
+ * @deprecated as of 7.0 use the <code><a href="{@docRoot}/org/apache/geode/management/package-summary.html">management</a></code> package instead
  */
 public interface ManagedEntityConfig extends Cloneable {
diff --git a/geode-core/src/main/java/org/apache/geode/admin/MemberHealthConfig.java b/geode-core/src/main/java/org/apache/geode/admin/MemberHealthConfig.java
index f9c332d..e0a90c6 100644
--- a/geode-core/src/main/java/org/apache/geode/admin/MemberHealthConfig.java
+++ b/geode-core/src/main/java/org/apache/geode/admin/MemberHealthConfig.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.admin;
+package org.apache.geode.admin;
 
 /**
  * Provides configuration information relating to the health of a
@@ -47,7 +47,7 @@ package com.gemstone.gemfire.admin;
  *
  *
  * @since GemFire 3.5
  * @deprecated as of 7.0 use the <code><a href="{@docRoot}/com/gemstone/gemfire/management/package-summary.html">management</a></code> package instead
  * */
 public interface MemberHealthConfig {
 

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/admin/OperationCancelledException.java
----------------------------------------------------------------------
@@ -47,7 +47,7 @@ package com.gemstone.gemfire.admin;
  *
  * @since GemFire 3.5
- * @deprecated as of 7.0 use the <code><a href="{@docRoot}/com/gemstone/gemfire/management/package-summary.html">management</a></code> package instead
+ * @deprecated as of 7.0 use the <code><a href="{@docRoot}/org/apache/geode/management/package-summary.html">management</a></code> package instead
  * */
 public interface MemberHealthConfig {
diff --git a/geode-core/src/main/java/org/apache/geode/admin/OperationCancelledException.java b/geode-core/src/main/java/org/apache/geode/admin/OperationCancelledException.java
index 5132626..d765c21 100644
--- a/geode-core/src/main/java/org/apache/geode/admin/OperationCancelledException.java
+++ b/geode-core/src/main/java/org/apache/geode/admin/OperationCancelledException.java
@@ -15,9 +15,9 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.admin;
+package org.apache.geode.admin;
 
-//import com.gemstone.gemfire.GemFireException;
+//import org.apache.geode.GemFireException;
 
 /**
  * Thrown when an administration operation that accesses information
@@ -25,7 +25,7 @@ package com.gemstone.gemfire.admin;
  * because the system member has left the distributed system.
  *
  * @since GemFire 3.5
  * @deprecated as of 7.0 use the <code><a href="{@docRoot}/com/gemstone/gemfire/management/package-summary.html">management</a></code> package instead
  */
 public class OperationCancelledException extends RuntimeAdminException {
    private static final long serialVersionUID = 5474068770227602546L;

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/admin/RegionNotFoundException.java
----------------------------------------------------------------------
@@ -25,7 +25,7 @@ package com.gemstone.gemfire.admin;
  *
  * @since GemFire 3.5
- * @deprecated as of 7.0 use the <code><a href="{@docRoot}/com/gemstone/gemfire/management/package-summary.html">management</a></code> package instead
+ * @deprecated as of 7.0 use the <code><a href="{@docRoot}/org/apache/geode/management/package-summary.html">management</a></code> package instead
  */
 public class OperationCancelledException extends RuntimeAdminException {
diff --git a/geode-core/src/main/java/org/apache/geode/admin/RegionNotFoundException.java b/geode-core/src/main/java/org/apache/geode/admin/RegionNotFoundException.java
index 18a86f4..29dfa98 100644
--- a/geode-core/src/main/java/org/apache/geode/admin/RegionNotFoundException.java
+++ b/geode-core/src/main/java/org/apache/geode/admin/RegionNotFoundException.java
@@ -14,20 +14,20 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.admin;
+package org.apache.geode.admin;
 
-//import com.gemstone.gemfire.cache.CacheException;
-import com.gemstone.gemfire.cache.CacheRuntimeException;
+//import org.apache.geode.cache.CacheException;
+import org.apache.geode.cache.CacheRuntimeException;
 
 /**
  * Thrown by the administration API when the region administered by a
  * {@link SystemMemberRegion} has been closed or destroyed in system
  * member. 
- * <P>Also thrown by {@link com.gemstone.gemfire.DataSerializer#readRegion(java.io.DataInput)}
+ * <P>Also thrown by {@link org.apache.geode.DataSerializer#readRegion(java.io.DataInput)}
  * if the named region no longer exists.
  *
  * @since GemFire 3.5
  * @deprecated as of 7.0 use the <code><a href="{@docRoot}/com/gemstone/gemfire/management/package-summary.html">management</a></code> package instead
  */
 public class RegionNotFoundException extends CacheRuntimeException {
 private static final long serialVersionUID = 1758668137691463909L;

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/admin/RegionSubRegionSnapshot.java
----------------------------------------------------------------------
@@ -14,20 +14,20 @@
  *
  * @since GemFire 3.5
- * @deprecated as of 7.0 use the <code><a href="{@docRoot}/com/gemstone/gemfire/management/package-summary.html">management</a></code> package instead
+ * @deprecated as of 7.0 use the <code><a href="{@docRoot}/org/apache/geode/management/package-summary.html">management</a></code> package instead
  */
 public class RegionNotFoundException extends CacheRuntimeException {
diff --git a/geode-core/src/main/java/org/apache/geode/admin/RegionSubRegionSnapshot.java b/geode-core/src/main/java/org/apache/geode/admin/RegionSubRegionSnapshot.java
index 42ae983..1945566 100644
--- a/geode-core/src/main/java/org/apache/geode/admin/RegionSubRegionSnapshot.java
+++ b/geode-core/src/main/java/org/apache/geode/admin/RegionSubRegionSnapshot.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.admin;
+package org.apache.geode.admin;
 
 import java.io.DataInput;
 import java.io.DataOutput;
@@ -23,11 +23,11 @@ import java.util.HashSet;
 import java.util.Iterator;
 import java.util.Set;
 
-import com.gemstone.gemfire.DataSerializable;
-import com.gemstone.gemfire.DataSerializer;
-import com.gemstone.gemfire.cache.Region;
-import com.gemstone.gemfire.i18n.LogWriterI18n;
-import com.gemstone.gemfire.internal.cache.PartitionedRegion;
+import org.apache.geode.DataSerializable;
+import org.apache.geode.DataSerializer;
+import org.apache.geode.cache.Region;
+import org.apache.geode.i18n.LogWriterI18n;
+import org.apache.geode.internal.cache.PartitionedRegion;
 
 /**
  * Class <code>RegionSubRegionSnapshot</code> provides information about
@@ -36,7 +36,7 @@ import com.gemstone.gemfire.internal.cache.PartitionedRegion;
  * 
  * 
  * @since GemFire 5.7
  * @deprecated as of 7.0 use the <code><a href="{@docRoot}/com/gemstone/gemfire/management/package-summary.html">management</a></code> package instead
  */
 public class RegionSubRegionSnapshot implements DataSerializable {
   private static final long serialVersionUID = -8052137675270041871L;

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/admin/RuntimeAdminException.java
----------------------------------------------------------------------
@@ -36,7 +36,7 @@ import com.gemstone.gemfire.internal.cache.PartitionedRegion;
  * 
  * @since GemFire 5.7
- * @deprecated as of 7.0 use the <code><a href="{@docRoot}/com/gemstone/gemfire/management/package-summary.html">management</a></code> package instead
+ * @deprecated as of 7.0 use the <code><a href="{@docRoot}/org/apache/geode/management/package-summary.html">management</a></code> package instead
  */
 public class RegionSubRegionSnapshot implements DataSerializable {
diff --git a/geode-core/src/main/java/org/apache/geode/admin/RuntimeAdminException.java b/geode-core/src/main/java/org/apache/geode/admin/RuntimeAdminException.java
index 08f5efc..7a28867 100755
--- a/geode-core/src/main/java/org/apache/geode/admin/RuntimeAdminException.java
+++ b/geode-core/src/main/java/org/apache/geode/admin/RuntimeAdminException.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
    
-package com.gemstone.gemfire.admin;
+package org.apache.geode.admin;
 
 /**
  * A <code>RuntimeAdminException</code> is thrown when a runtime errors occurs
@@ -23,10 +23,10 @@ package com.gemstone.gemfire.admin;
  *
  * @since GemFire     3.5
  *
  * @deprecated as of 7.0 use the <code><a href="{@docRoot}/com/gemstone/gemfire/management/package-summary.html">management</a></code> package instead
  */
 public class RuntimeAdminException 
-extends com.gemstone.gemfire.GemFireException {
+extends org.apache.geode.GemFireException {
 
   private static final long serialVersionUID = -7512771113818634005L;
 

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/admin/Statistic.java
----------------------------------------------------------------------
@@ -23,10 +23,10 @@ package com.gemstone.gemfire.admin;
  * @since GemFire     3.5
  *
- * @deprecated as of 7.0 use the <code><a href="{@docRoot}/com/gemstone/gemfire/management/package-summary.html">management</a></code> package instead
+ * @deprecated as of 7.0 use the <code><a href="{@docRoot}/org/apache/geode/management/package-summary.html">management</a></code> package instead
  */
 public class RuntimeAdminException 
diff --git a/geode-core/src/main/java/org/apache/geode/admin/Statistic.java b/geode-core/src/main/java/org/apache/geode/admin/Statistic.java
index 731d024..b1f1cc8 100755
--- a/geode-core/src/main/java/org/apache/geode/admin/Statistic.java
+++ b/geode-core/src/main/java/org/apache/geode/admin/Statistic.java
@@ -15,14 +15,14 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.admin;
+package org.apache.geode.admin;
 
 /**
  * Interface to represent a single statistic of a <code>StatisticResource</code>
  *
  * @since GemFire     3.5
  *
  * @deprecated as of 7.0 use the <code><a href="{@docRoot}/com/gemstone/gemfire/management/package-summary.html">management</a></code> package instead
  */
 public interface Statistic extends java.io.Serializable {
     

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/admin/StatisticResource.java
----------------------------------------------------------------------
@@ -15,14 +15,14 @@
  * @since GemFire     3.5
  *
- * @deprecated as of 7.0 use the <code><a href="{@docRoot}/com/gemstone/gemfire/management/package-summary.html">management</a></code> package instead
+ * @deprecated as of 7.0 use the <code><a href="{@docRoot}/org/apache/geode/management/package-summary.html">management</a></code> package instead
  */
 public interface Statistic extends java.io.Serializable {
diff --git a/geode-core/src/main/java/org/apache/geode/admin/StatisticResource.java b/geode-core/src/main/java/org/apache/geode/admin/StatisticResource.java
index 3344b25..43c51cd 100755
--- a/geode-core/src/main/java/org/apache/geode/admin/StatisticResource.java
+++ b/geode-core/src/main/java/org/apache/geode/admin/StatisticResource.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.admin;
+package org.apache.geode.admin;
 
 /**
  * Adminitrative interface for monitoring a statistic resource in a GemFire
@@ -23,7 +23,7 @@ package com.gemstone.gemfire.admin;
  *
  * @since GemFire     3.5
  *
  * @deprecated as of 7.0 use the <code><a href="{@docRoot}/com/gemstone/gemfire/management/package-summary.html">management</a></code> package instead
  */
 public interface StatisticResource {
   
@@ -76,10 +76,10 @@ public interface StatisticResource {
    * Refreshes the values of every {@link Statistic} in this resource by
    * retrieving them from the member's VM.
    *
-   * @throws com.gemstone.gemfire.admin.AdminException 
+   * @throws org.apache.geode.admin.AdminException 
    *         if unable to refresh statistic values
    */
-  public void refresh() throws com.gemstone.gemfire.admin.AdminException;
+  public void refresh() throws org.apache.geode.admin.AdminException;
   
 }
 

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/admin/SystemMember.java
----------------------------------------------------------------------
@@ -23,7 +23,7 @@ package com.gemstone.gemfire.admin;
  * @since GemFire     3.5
  *
- * @deprecated as of 7.0 use the <code><a href="{@docRoot}/com/gemstone/gemfire/management/package-summary.html">management</a></code> package instead
+ * @deprecated as of 7.0 use the <code><a href="{@docRoot}/org/apache/geode/management/package-summary.html">management</a></code> package instead
  */
 public interface StatisticResource {
diff --git a/geode-core/src/main/java/org/apache/geode/admin/SystemMember.java b/geode-core/src/main/java/org/apache/geode/admin/SystemMember.java
index 2667b3d..78cc9aa 100755
--- a/geode-core/src/main/java/org/apache/geode/admin/SystemMember.java
+++ b/geode-core/src/main/java/org/apache/geode/admin/SystemMember.java
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.admin;
+package org.apache.geode.admin;
 
-import com.gemstone.gemfire.distributed.DistributedMember;
+import org.apache.geode.distributed.DistributedMember;
 
 import java.net.InetAddress;
 
@@ -25,7 +25,7 @@ import java.net.InetAddress;
  *
  * @since GemFire     3.5
  *
  * @deprecated as of 7.0 use the <code><a href="{@docRoot}/com/gemstone/gemfire/management/package-summary.html">management</a></code> package instead
  */
 public interface SystemMember {
   
@@ -43,10 +43,10 @@ public interface SystemMember {
    * Retrieves display friendly name for this member.  If this member defined 
    * an optional name for its connection to the distributed system, that name 
    * will be returned.  Otherwise the returned value will be {@link
-   * com.gemstone.gemfire.admin.SystemMember#getId}.
+   * org.apache.geode.admin.SystemMember#getId}.
    *
-   * @see com.gemstone.gemfire.distributed.DistributedSystem#connect
-   * @see com.gemstone.gemfire.distributed.DistributedSystem#getName
+   * @see org.apache.geode.distributed.DistributedSystem#connect
+   * @see org.apache.geode.distributed.DistributedSystem#getName
    */
   public String getName();
   
@@ -86,13 +86,13 @@ public interface SystemMember {
    *
    * @param parms subset of the configuration parameters to be changed
    * @return all configuration parameters including those that were changed
-   * @throws com.gemstone.gemfire.admin.AdminException
+   * @throws org.apache.geode.admin.AdminException
    *         if this fails to make the configuration changes
    */
-  public ConfigurationParameter[] setConfiguration(ConfigurationParameter[] parms) throws com.gemstone.gemfire.admin.AdminException;
+  public ConfigurationParameter[] setConfiguration(ConfigurationParameter[] parms) throws org.apache.geode.admin.AdminException;
   
   /** Refreshes this member's configuration from the member or it's properties */
-  public void refreshConfig() throws com.gemstone.gemfire.admin.AdminException;
+  public void refreshConfig() throws org.apache.geode.admin.AdminException;
   
   /** 
    * Retrieves this members statistic resources. If the member is not running 
@@ -102,7 +102,7 @@ public interface SystemMember {
    * @return array of runtime statistic resources owned by this member
    * @since GemFire 5.7
    */
-  public StatisticResource[] getStat(String statisticsTypeName) throws com.gemstone.gemfire.admin.AdminException;
+  public StatisticResource[] getStat(String statisticsTypeName) throws org.apache.geode.admin.AdminException;
   
   /** 
    * Retrieves this members statistic resources. If the member is not running 
@@ -110,22 +110,22 @@ public interface SystemMember {
    *
    * @return array of runtime statistic resources owned by this member
    */
-  public StatisticResource[] getStats() throws com.gemstone.gemfire.admin.AdminException;
+  public StatisticResource[] getStats() throws org.apache.geode.admin.AdminException;
   
   /**
    * Returns whether or not this system member hosts a GemFire {@link
-   * com.gemstone.gemfire.cache.Cache Cache}.
+   * org.apache.geode.cache.Cache Cache}.
    *
    * @see #getCache
    */
   public boolean hasCache()
-    throws com.gemstone.gemfire.admin.AdminException;
+    throws org.apache.geode.admin.AdminException;
 
   /**
    * Returns an object that provides admin access to this member's cache.
    * If the member currently has no cache then <code>null</code> is returned.
    */
-  public SystemMemberCache getCache() throws com.gemstone.gemfire.admin.AdminException;
+  public SystemMemberCache getCache() throws org.apache.geode.admin.AdminException;
   
   /**
    * Returns the names of the membership roles filled by this member.
@@ -136,7 +136,7 @@ public interface SystemMember {
   public String[] getRoles();
   
   /**
-   * Returns the {@link com.gemstone.gemfire.distributed.DistributedMember}
+   * Returns the {@link org.apache.geode.distributed.DistributedMember}
    * that represents this system member.
    *
    * @return DistributedMember instance representing this system member

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/admin/SystemMemberBridgeServer.java
----------------------------------------------------------------------
@@ -25,7 +25,7 @@ import java.net.InetAddress;
  * @since GemFire     3.5
  *
- * @deprecated as of 7.0 use the <code><a href="{@docRoot}/com/gemstone/gemfire/management/package-summary.html">management</a></code> package instead
+ * @deprecated as of 7.0 use the <code><a href="{@docRoot}/org/apache/geode/management/package-summary.html">management</a></code> package instead
  */
 public interface SystemMember {
diff --git a/geode-core/src/main/java/org/apache/geode/admin/SystemMemberCache.java b/geode-core/src/main/java/org/apache/geode/admin/SystemMemberCache.java
index 8c178dd..2c194ca 100644
--- a/geode-core/src/main/java/org/apache/geode/admin/SystemMemberCache.java
+++ b/geode-core/src/main/java/org/apache/geode/admin/SystemMemberCache.java
@@ -14,16 +14,16 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.admin;
+package org.apache.geode.admin;
 
-import com.gemstone.gemfire.cache.RegionAttributes;
+import org.apache.geode.cache.RegionAttributes;
 
 /**
  * Administrative interface that represent's the {@link SystemMember}'s view
- * of its {@link com.gemstone.gemfire.cache.Cache}.
+ * of its {@link org.apache.geode.cache.Cache}.
  *
  * @since GemFire     3.5
  * @deprecated as of 7.0 use the <code><a href="{@docRoot}/com/gemstone/gemfire/management/package-summary.html">management</a></code> package instead
  */
 public interface SystemMemberCache {
   // attributes
@@ -53,7 +53,7 @@ public interface SystemMemberCache {
    *         If a problem is encountered while setting the lock
    *         timeout 
    *
-   * @see com.gemstone.gemfire.cache.Cache#setLockTimeout
+   * @see org.apache.geode.cache.Cache#setLockTimeout
    */
   public void setLockTimeout(int seconds) throws AdminException;
   
@@ -70,13 +70,13 @@ public interface SystemMemberCache {
    *         If a problem is encountered while setting the lock
    *         lease
    *
-   * @see com.gemstone.gemfire.cache.Cache#setLockLease
+   * @see org.apache.geode.cache.Cache#setLockLease
    */
   public void setLockLease(int seconds) throws AdminException;
   
   /**
    * Gets the number of seconds a cache
-   * {@link com.gemstone.gemfire.cache.Region#get(Object) get} operation
+   * {@link org.apache.geode.cache.Region#get(Object) get} operation
    * can spend searching for a value before it times out.
    * The search includes any time spent loading the object.
    * When the search times out it causes the get to fail by throwing
@@ -91,7 +91,7 @@ public interface SystemMemberCache {
    *         If a problem is encountered while setting the search
    *         timeout 
    *
-   * @see com.gemstone.gemfire.cache.Cache#setSearchTimeout
+   * @see org.apache.geode.cache.Cache#setSearchTimeout
    */
   public void setSearchTimeout(int seconds) throws AdminException;
   /**
@@ -171,7 +171,7 @@ public interface SystemMemberCache {
    * Adds a new, unstarted cache server that will serve the contents
    * of this cache to clients.
    *
-   * @see com.gemstone.gemfire.cache.Cache#addCacheServer
+   * @see org.apache.geode.cache.Cache#addCacheServer
    *
    * @since GemFire 5.7
    */
@@ -183,7 +183,7 @@ public interface SystemMemberCache {
    * that this list will not be updated until {@link #refresh} is
    * called.
    *
-   * @see com.gemstone.gemfire.cache.Cache#getCacheServers
+   * @see org.apache.geode.cache.Cache#getCacheServers
    *
    * @since GemFire 5.7
    */

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/admin/SystemMemberCacheEvent.java
----------------------------------------------------------------------
@@ -14,16 +14,16 @@
  *
  * @since GemFire     3.5
- * @deprecated as of 7.0 use the <code><a href="{@docRoot}/com/gemstone/gemfire/management/package-summary.html">management</a></code> package instead
+ * @deprecated as of 7.0 use the <code><a href="{@docRoot}/org/apache/geode/management/package-summary.html">management</a></code> package instead
  */
 public interface SystemMemberCache {
diff --git a/geode-core/src/main/java/org/apache/geode/admin/SystemMemberCacheEvent.java b/geode-core/src/main/java/org/apache/geode/admin/SystemMemberCacheEvent.java
index 4b1454c..dee9bc1 100644
--- a/geode-core/src/main/java/org/apache/geode/admin/SystemMemberCacheEvent.java
+++ b/geode-core/src/main/java/org/apache/geode/admin/SystemMemberCacheEvent.java
@@ -14,16 +14,16 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.admin;
+package org.apache.geode.admin;
 
-import com.gemstone.gemfire.cache.Operation;
+import org.apache.geode.cache.Operation;
 /**
  * An event that describes an operation on a cache.
  * Instances of this are delivered to a {@link SystemMemberCacheListener} when a
  * a cache is created or closed.
  *
  * @since GemFire 5.0
  * @deprecated as of 7.0 use the <code><a href="{@docRoot}/com/gemstone/gemfire/management/package-summary.html">management</a></code> package instead
  */
 public interface SystemMemberCacheEvent extends SystemMembershipEvent {
   /**

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/admin/SystemMemberCacheListener.java
----------------------------------------------------------------------
@@ -14,16 +14,16 @@
  *
  * @since GemFire 5.0
- * @deprecated as of 7.0 use the <code><a href="{@docRoot}/com/gemstone/gemfire/management/package-summary.html">management</a></code> package instead
+ * @deprecated as of 7.0 use the <code><a href="{@docRoot}/org/apache/geode/management/package-summary.html">management</a></code> package instead
  */
 public interface SystemMemberCacheEvent extends SystemMembershipEvent {
diff --git a/geode-core/src/main/java/org/apache/geode/admin/SystemMemberCacheListener.java b/geode-core/src/main/java/org/apache/geode/admin/SystemMemberCacheListener.java
index b46bdf0..0d258b6 100644
--- a/geode-core/src/main/java/org/apache/geode/admin/SystemMemberCacheListener.java
+++ b/geode-core/src/main/java/org/apache/geode/admin/SystemMemberCacheListener.java
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.admin;
+package org.apache.geode.admin;
 
-import com.gemstone.gemfire.cache.*;
+import org.apache.geode.cache.*;
 
 /**
  * A listener whose callback methods can be used to track the lifecycle of
@@ -26,7 +26,7 @@ import com.gemstone.gemfire.cache.*;
  * @see AdminDistributedSystem#removeCacheListener
  *
  * @since GemFire 5.0
  * @deprecated as of 7.0 use the <code><a href="{@docRoot}/com/gemstone/gemfire/management/package-summary.html">management</a></code> package instead
  */
 public interface SystemMemberCacheListener {
 

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/admin/SystemMemberCacheServer.java
----------------------------------------------------------------------
@@ -26,7 +26,7 @@ import com.gemstone.gemfire.cache.*;
  *
  * @since GemFire 5.0
- * @deprecated as of 7.0 use the <code><a href="{@docRoot}/com/gemstone/gemfire/management/package-summary.html">management</a></code> package instead
+ * @deprecated as of 7.0 use the <code><a href="{@docRoot}/org/apache/geode/management/package-summary.html">management</a></code> package instead
  */
 public interface SystemMemberCacheListener {
diff --git a/geode-core/src/main/java/org/apache/geode/admin/SystemMemberCacheServer.java b/geode-core/src/main/java/org/apache/geode/admin/SystemMemberCacheServer.java
index 86097bb..daf2199 100755
--- a/geode-core/src/main/java/org/apache/geode/admin/SystemMemberCacheServer.java
+++ b/geode-core/src/main/java/org/apache/geode/admin/SystemMemberCacheServer.java
@@ -14,19 +14,19 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.admin;
+package org.apache.geode.admin;
 
-import com.gemstone.gemfire.cache.server.ServerLoadProbe;
+import org.apache.geode.cache.server.ServerLoadProbe;
 
 /**
  * Administrative interface that represents a {@link
- * com.gemstone.gemfire.cache.server.CacheServer CacheServer} that
+ * org.apache.geode.cache.server.CacheServer CacheServer} that
  * serves the contents of a system member's cache to clients. 
  *
  * @see SystemMemberCache#addCacheServer
  *
  * @since GemFire 5.7
  * @deprecated as of 7.0 use the <code><a href="{@docRoot}/com/gemstone/gemfire/management/package-summary.html">management</a></code> package instead
  */
 public interface SystemMemberCacheServer {
 
@@ -84,7 +84,7 @@ public interface SystemMemberCacheServer {
    * <p>Setting a specific bind address will cause the cache server to always
    * use this address and ignore any address specified by "server-bind-address"
    * or "bind-address" in the <code>gemfire.properties</code> file
-   * (see {@link com.gemstone.gemfire.distributed.DistributedSystem}
+   * (see {@link org.apache.geode.distributed.DistributedSystem}
    * for a description of these properties).
    * <p> A <code>null</code> value will be treated the same as the default "".
    * <p> The default value does not override the gemfire.properties. If you wish to

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/admin/SystemMemberRegion.java
----------------------------------------------------------------------
@@ -14,19 +14,19 @@
  *
  * @since GemFire 5.7
- * @deprecated as of 7.0 use the <code><a href="{@docRoot}/com/gemstone/gemfire/management/package-summary.html">management</a></code> package instead
+ * @deprecated as of 7.0 use the <code><a href="{@docRoot}/org/apache/geode/management/package-summary.html">management</a></code> package instead
  */
 public interface SystemMemberCacheServer {
diff --git a/geode-core/src/main/java/org/apache/geode/admin/SystemMemberRegion.java b/geode-core/src/main/java/org/apache/geode/admin/SystemMemberRegion.java
index b55c21f..22acdcc 100644
--- a/geode-core/src/main/java/org/apache/geode/admin/SystemMemberRegion.java
+++ b/geode-core/src/main/java/org/apache/geode/admin/SystemMemberRegion.java
@@ -14,28 +14,28 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.admin;
+package org.apache.geode.admin;
 
-import com.gemstone.gemfire.cache.*;
+import org.apache.geode.cache.*;
 import java.io.File;
 
 /**
  * Administrative interface that represent's the {@link
  * SystemMember}'s view of one of its cache's {@link
  * com.gemstone.gemfire.cache.Region}s.  If the region in the remote
  * system member is closed or destroyed, the methods of
  * <code>SystemMemberRegion</code> will throw {@link
  * RegionNotFoundException}.
  *
  * @since GemFire 3.5
  * @deprecated as of 7.0 use the <code><a href="{@docRoot}/com/gemstone/gemfire/management/package-summary.html">management</a></code> package instead
  */
 public interface SystemMemberRegion {
   // attributes
   /**
    * Returns the name that identifies this region in its cache.
    *
-   * @see com.gemstone.gemfire.cache.Region#getName
+   * @see org.apache.geode.cache.Region#getName
    */
   public String getName();
   
@@ -43,7 +43,7 @@ public interface SystemMemberRegion {
    * Returns the full path name that identifies this region in its
    * cache.
    *
-   * @see com.gemstone.gemfire.cache.Region#getFullPath
+   * @see org.apache.geode.cache.Region#getFullPath
    */
   public String getFullPath();
 

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/admin/SystemMemberRegionEvent.java
----------------------------------------------------------------------
@@ -14,28 +14,28 @@
  * Administrative interface that represent's the {@link
  * SystemMember}'s view of one of its cache's {@link
- * com.gemstone.gemfire.cache.Region}s.  If the region in the remote
+ * org.apache.geode.cache.Region}s.  If the region in the remote
  * system member is closed or destroyed, the methods of
  * <code>SystemMemberRegion</code> will throw {@link
@@ -14,28 +14,28 @@
  *
  * @since GemFire 3.5
- * @deprecated as of 7.0 use the <code><a href="{@docRoot}/com/gemstone/gemfire/management/package-summary.html">management</a></code> package instead
+ * @deprecated as of 7.0 use the <code><a href="{@docRoot}/org/apache/geode/management/package-summary.html">management</a></code> package instead
  */
 public interface SystemMemberRegion {
diff --git a/geode-core/src/main/java/org/apache/geode/admin/SystemMemberRegionEvent.java b/geode-core/src/main/java/org/apache/geode/admin/SystemMemberRegionEvent.java
index c391263..2dd1ffd 100644
--- a/geode-core/src/main/java/org/apache/geode/admin/SystemMemberRegionEvent.java
+++ b/geode-core/src/main/java/org/apache/geode/admin/SystemMemberRegionEvent.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.admin;
+package org.apache.geode.admin;
 
 /**
  * An event that describes an operation on a region.
@@ -22,7 +22,7 @@ package com.gemstone.gemfire.admin;
  * a region comes or goes.
  *
  * @since GemFire 5.0
  * @deprecated as of 7.0 use the <code><a href="{@docRoot}/com/gemstone/gemfire/management/package-summary.html">management</a></code> package instead
  */
 public interface SystemMemberRegionEvent extends SystemMemberCacheEvent {
   /**

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/admin/SystemMemberType.java
----------------------------------------------------------------------
@@ -22,7 +22,7 @@ package com.gemstone.gemfire.admin;
  *
  * @since GemFire 5.0
- * @deprecated as of 7.0 use the <code><a href="{@docRoot}/com/gemstone/gemfire/management/package-summary.html">management</a></code> package instead
+ * @deprecated as of 7.0 use the <code><a href="{@docRoot}/org/apache/geode/management/package-summary.html">management</a></code> package instead
  */
 public interface SystemMemberRegionEvent extends SystemMemberCacheEvent {
diff --git a/geode-core/src/main/java/org/apache/geode/admin/SystemMemberType.java b/geode-core/src/main/java/org/apache/geode/admin/SystemMemberType.java
index 1e3e1aa..7ba99fb 100755
--- a/geode-core/src/main/java/org/apache/geode/admin/SystemMemberType.java
+++ b/geode-core/src/main/java/org/apache/geode/admin/SystemMemberType.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.admin;
+package org.apache.geode.admin;
 
 //import java.io.*;
 
@@ -23,7 +23,7 @@ package com.gemstone.gemfire.admin;
  *
  * @since GemFire     3.5
  *
  * @deprecated as of 7.0 use the <code><a href="{@docRoot}/com/gemstone/gemfire/management/package-summary.html">management</a></code> package instead
  */
 public class SystemMemberType implements java.io.Serializable {
   private static final long serialVersionUID = 3284366994485749302L;

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/admin/SystemMembershipEvent.java
----------------------------------------------------------------------
@@ -23,7 +23,7 @@ package com.gemstone.gemfire.admin;
  * @since GemFire     3.5
  *
- * @deprecated as of 7.0 use the <code><a href="{@docRoot}/com/gemstone/gemfire/management/package-summary.html">management</a></code> package instead
+ * @deprecated as of 7.0 use the <code><a href="{@docRoot}/org/apache/geode/management/package-summary.html">management</a></code> package instead
  */
 public class SystemMemberType implements java.io.Serializable {
diff --git a/geode-core/src/main/java/org/apache/geode/admin/SystemMembershipEvent.java b/geode-core/src/main/java/org/apache/geode/admin/SystemMembershipEvent.java
index c428043..9319de5 100644
--- a/geode-core/src/main/java/org/apache/geode/admin/SystemMembershipEvent.java
+++ b/geode-core/src/main/java/org/apache/geode/admin/SystemMembershipEvent.java
@@ -14,16 +14,16 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.admin;
+package org.apache.geode.admin;
 
-import com.gemstone.gemfire.distributed.DistributedMember;
+import org.apache.geode.distributed.DistributedMember;
 /**
  * An event that describes the distributed member originated this event.
  * Instances of this are delivered to a {@link SystemMembershipListener} when a
  * member has joined or left the distributed system.
  *
  * @since GemFire 3.5
  * @deprecated as of 7.0 use the <code><a href="{@docRoot}/com/gemstone/gemfire/management/package-summary.html">management</a></code> package instead
  */
 public interface SystemMembershipEvent {
   /**

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/admin/SystemMembershipListener.java
----------------------------------------------------------------------
@@ -14,16 +14,16 @@
  *
  * @since GemFire 3.5
- * @deprecated as of 7.0 use the <code><a href="{@docRoot}/com/gemstone/gemfire/management/package-summary.html">management</a></code> package instead
+ * @deprecated as of 7.0 use the <code><a href="{@docRoot}/org/apache/geode/management/package-summary.html">management</a></code> package instead
  */
 public interface SystemMembershipEvent {
diff --git a/geode-core/src/main/java/org/apache/geode/admin/SystemMembershipListener.java b/geode-core/src/main/java/org/apache/geode/admin/SystemMembershipListener.java
index a8b8b3d..b1d6afe 100644
--- a/geode-core/src/main/java/org/apache/geode/admin/SystemMembershipListener.java
+++ b/geode-core/src/main/java/org/apache/geode/admin/SystemMembershipListener.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.admin;
+package org.apache.geode.admin;
 
 /**
  * A listener whose callback methods are invoked when members join or
@@ -23,7 +23,7 @@ package com.gemstone.gemfire.admin;
  * @see AdminDistributedSystem#addMembershipListener
  *
  * @since GemFire 3.5
  * @deprecated as of 7.0 use the <code><a href="{@docRoot}/com/gemstone/gemfire/management/package-summary.html">management</a></code> package instead
  */
 public interface SystemMembershipListener {
 
@@ -52,7 +52,7 @@ public interface SystemMembershipListener {
 //   /**
 //    * Invoked when a member broadcasts an informational message.
 //    *
-//    * @see com.gemstone.gemfire.distributed.DistributedSystem#fireInfoEvent
+//    * @see org.apache.geode.distributed.DistributedSystem#fireInfoEvent
 //    *
 //    * @since GemFire 4.0
 //    */

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/admin/UnmodifiableConfigurationException.java
----------------------------------------------------------------------
@@ -23,7 +23,7 @@ package com.gemstone.gemfire.admin;
  *
  * @since GemFire 3.5
- * @deprecated as of 7.0 use the <code><a href="{@docRoot}/com/gemstone/gemfire/management/package-summary.html">management</a></code> package instead
+ * @deprecated as of 7.0 use the <code><a href="{@docRoot}/org/apache/geode/management/package-summary.html">management</a></code> package instead
  */
 public interface SystemMembershipListener {
diff --git a/geode-core/src/main/java/org/apache/geode/admin/UnmodifiableConfigurationException.java b/geode-core/src/main/java/org/apache/geode/admin/UnmodifiableConfigurationException.java
index a73b0bf..e89fc96 100755
--- a/geode-core/src/main/java/org/apache/geode/admin/UnmodifiableConfigurationException.java
+++ b/geode-core/src/main/java/org/apache/geode/admin/UnmodifiableConfigurationException.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
    
-package com.gemstone.gemfire.admin;
+package org.apache.geode.admin;
 
 /**
  * An <code>UnmodifiableConfigurationException</code> is thrown when an attempt
@@ -24,7 +24,7 @@ package com.gemstone.gemfire.admin;
  *
  * @since GemFire     3.5
  *
  * @deprecated as of 7.0 use the <code><a href="{@docRoot}/com/gemstone/gemfire/management/package-summary.html">management</a></code> package instead
  */
 public class UnmodifiableConfigurationException extends AdminException {
 private static final long serialVersionUID = -7653547392992060646L;

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/admin/internal/AbstractHealthEvaluator.java
----------------------------------------------------------------------
@@ -24,7 +24,7 @@ package com.gemstone.gemfire.admin;
  * @since GemFire     3.5
  *
- * @deprecated as of 7.0 use the <code><a href="{@docRoot}/com/gemstone/gemfire/management/package-summary.html">management</a></code> package instead
+ * @deprecated as of 7.0 use the <code><a href="{@docRoot}/org/apache/geode/management/package-summary.html">management</a></code> package instead
  */
 public class UnmodifiableConfigurationException extends AdminException {
diff --git a/geode-core/src/main/java/org/apache/geode/admin/internal/ConfigurationParameterListener.java b/geode-core/src/main/java/org/apache/geode/admin/internal/ConfigurationParameterListener.java
index c2f23e4..b9102d6 100755
--- a/geode-core/src/main/java/org/apache/geode/admin/internal/ConfigurationParameterListener.java
+++ b/geode-core/src/main/java/org/apache/geode/admin/internal/ConfigurationParameterListener.java
@@ -14,13 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.admin.internal;
+package org.apache.geode.admin.internal;
 
-import com.gemstone.gemfire.admin.ConfigurationParameter;
+import org.apache.geode.admin.ConfigurationParameter;
 
 /**
  * Listens to value changes of a 
  * {@link com.gemstone.gemfire.admin.ConfigurationParameter}.  This is for 
  * internal use only to allow a {@link SystemMemberImpl} to keep track of 
  * configuration changes made through 
  * {@link ConfigurationParameterImpl#setValue}.

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/admin/internal/DisabledManagedEntityController.java
----------------------------------------------------------------------
@@ -14,13 +14,13 @@
 /**
  * Listens to value changes of a 
- * {@link com.gemstone.gemfire.admin.ConfigurationParameter}.  This is for 
+ * {@link org.apache.geode.admin.ConfigurationParameter}.  This is for 
  * internal use only to allow a {@link SystemMemberImpl} to keep track of 
  * configuration changes made through 